@@ -66,42 +66,5 @@ PangoFontMap *_gtk_source_utils_get_builder_blocks       (void);
 G_GNUC_INTERNAL
 gsize    _gtk_source_utils_strnlen                       (const char                  *str,
                                                           gsize                        maxlen);
-G_GNUC_INTERNAL
-void     _gtk_source_widget_add_css_provider             (GtkWidget                   *widget,
-                                                          GtkCssProvider              *provider,
-							  guint                        priority);
-G_GNUC_INTERNAL
-void     _gtk_source_widget_remove_css_provider          (GtkWidget                   *widget,
-                                                          GtkCssProvider              *provider);
-G_GNUC_INTERNAL
-void     _gtk_source_add_css_provider                    (GdkDisplay                  *display,
-                                                          GtkCssProvider              *provider,
-							  guint                        priority);
-
-static inline void
-premix_colors (GdkRGBA       *dest,
-               const GdkRGBA *fg,
-               const GdkRGBA *bg,
-               gboolean       bg_set,
-               double         alpha)
-{
-	g_assert (dest != NULL);
-	g_assert (fg != NULL);
-	g_assert (bg != NULL || bg_set == FALSE);
-	g_assert (alpha >= 0.0 && alpha <= 1.0);
-
-	if (bg_set)
-	{
-		dest->red = ((1 - alpha) * bg->red) + (alpha * fg->red);
-		dest->green = ((1 - alpha) * bg->green) + (alpha * fg->green);
-		dest->blue = ((1 - alpha) * bg->blue) + (alpha * fg->blue);
-		dest->alpha = 1.0;
-	}
-	else
-	{
-		*dest = *fg;
-		dest->alpha = alpha;
-	}
-}
 
 G_END_DECLS
